@@ -7,15 +7,17 @@ import sys
 from markups.common import CONFIGURATION_DIR
 from markups.markdown import MarkdownMarkup
 from markups.restructuredtext import ReStructuredTextMarkup
+from markups.textile import TextileMarkup
 
-__version__ = '0.3'
+__version_tuple__ = (0, 4)
+__version__ = '.'.join(map(str, __version_tuple__))
 
-builtin_markups = [MarkdownMarkup, ReStructuredTextMarkup]
+builtin_markups = [MarkdownMarkup, ReStructuredTextMarkup, TextileMarkup]
 
 # Public API
 
 def get_custom_markups():
-	try:	
+	try:
 		list_file = open(os.path.join(CONFIGURATION_DIR, 'pymarkups.txt'))
 	except IOError:
 		return []
