@@ -13,10 +13,10 @@ class ReStructuredTextMarkup(AbstractMarkup):
 		common.MODULE_HOME_PAGE: 'http://docutils.sourceforge.net/',
 		common.SYNTAX_DOCUMENTATION: 'http://docutils.sourceforge.net/docs/ref/rst/restructuredtext.html'
 	}
-	
+
 	file_extensions = ('.rst', '.rest')
 	default_extension = '.rst'
-	
+
 	@staticmethod
 	def available():
 		try:
@@ -24,28 +24,29 @@ class ReStructuredTextMarkup(AbstractMarkup):
 		except ImportError:
 			return False
 		return True
-	
-	def __init__(self, filename=None):
+
+	def __init__(self, filename=None, settings_overrides=None):
+		self.overrides = settings_overrides or {}
+		self.overrides.update({'math_output': 'MathJax'})
 		AbstractMarkup.__init__(self, filename)
 		from docutils.core import publish_parts
 		self._publish_parts = publish_parts
-	
+
 	def publish_parts(self, text):
 		if 'rest_parts' in self.cache:
 			return self.cache['rest_parts']
-		overrides = {'math_output': 'MathJax'}
-		parts = self._publish_parts(text, writer_name='html',
-			settings_overrides=overrides)
+		parts = self._publish_parts(text, source_path=self.filename,
+			writer_name='html', settings_overrides=self.overrides)
 		if self.enable_cache:
 			self.cache['rest_parts'] = parts
 		return parts
-	
+
 	def get_document_title(self, text):
 		return self.publish_parts(text)['title']
-	
+
 	def get_document_body(self, text):
 		return self.publish_parts(text)['body']
-	
+
 	def get_stylesheet(self, text=''):
 		origstyle = self.publish_parts(text)['stylesheet']
 		# Cut off <style> and </style> tags
@@ -54,7 +55,7 @@ class ReStructuredTextMarkup(AbstractMarkup):
 		if stylestart in origstyle:
 			stylesheet = origstyle[origstyle.find(stylestart)+25:origstyle.rfind('</style>')]
 		return stylesheet + common.get_pygments_stylesheet('.code')
-	
+
 	def get_javascript(self, text='', webenv=False):
 		head = self.publish_parts(text)['head']
 		start_position = head.find('<script ')
