@@ -11,6 +11,7 @@ basic_text = \
 
 This is an example **reStructuredText** document.'''
 
+@unittest.skipUnless(ReStructuredTextMarkup.available(), 'Docutils not available')
 class ReStructuredTextTest(unittest.TestCase):
 	def test_basic(self):
 		markup = ReStructuredTextMarkup()
@@ -26,7 +27,7 @@ class ReStructuredTextTest(unittest.TestCase):
 		self.assertEqual(text_expected, text_from_cache)
 		self.assertEqual(title_expected, title)
 		self.assertEqual(title_expected, title_from_cache)
-	
+
 	def test_mathjax_loading(self):
 		markup = ReStructuredTextMarkup()
 		self.assertEqual('', markup.get_javascript('Hello, world!'))
@@ -36,5 +37,18 @@ class ReStructuredTextTest(unittest.TestCase):
 		self.assertIn('<span class="math">', body)
 		self.assertIn(r'\(2+2\)</span>', body)
 
+	def test_errors(self):
+		markup = ReStructuredTextMarkup('/dev/null',
+			settings_overrides = {'warning_stream': False})
+		body = markup.get_document_body('`') # unclosed role
+		self.assertIn('system-message', body)
+		self.assertIn('/dev/null', body)
+
+	def test_errors_overridden(self):
+		markup = ReStructuredTextMarkup('/dev/null',
+			settings_overrides = {'report_level': 4})
+		body = markup.get_document_body('`') # unclosed role
+		self.assertNotIn('system-message', body)
+
 if __name__ == '__main__':
 	unittest.main()
